| Title: | Make R Environment Fresh Again |
|---|---|
| Description: | A simple way to unload none-base packages and remove all global variables. |
| Authors: | Shawn Lin [aut, cre] (ORCID: <https://orcid.org/0000-0001-5564-8371>) |
| Maintainer: | Shawn Lin <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.2 |
| Built: | 2026-06-01 11:01:43 UTC |
| Source: | https://github.com/shawnlinxl/freshr |
Ever experienced a time when you pass an R script to your colleague, and it does not work on their machine because you forgot to add a library import that you did interactively? freshr is here to help! By calling freshr::freshr() at the top of your every script, you create a fresh environment for you to test reproducibility before you send your script to someone else.
freshr(pkgexc = NULL, varexc = NULL)freshr(pkgexc = NULL, varexc = NULL)
pkgexc |
list of packages to exclude from removal |
varexc |
list of variables to exclude from removal |
This function returns no value. It is called for its side effect of cleaning up the global environment at script's start up/