Welcome to ClientVPS Mirrors

Help for package freshr
Type: Package
Title: Make R Environment Fresh Again
Version: 1.0.2
Description: A simple way to unload none-base packages and remove all global variables.
License: MIT + file LICENSE
URL: https://github.com/shawnlinxl/freshr
BugReports: https://github.com/shawnlinxl/freshr/issues
Encoding: UTF-8
RoxygenNote: 7.2.1
Suggests: testthat (≥ 3.0.0), usethis
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2022-10-03 16:42:40 UTC; shawn
Author: Shawn Lin ORCID iD [aut, cre]
Maintainer: Shawn Lin <shawnlin.xl@gmail.com>
Repository: CRAN
Date/Publication: 2022-10-03 17:20:02 UTC

Unload none-base packages and remove all objects from environment

Description

Ever experienced a time when you pass an R script to your colleague, and it does not work on their machine because you forgot to add a library import that you did interactively? freshr is here to help! By calling freshr::freshr() at the top of your every script, you create a fresh environment for you to test reproducibility before you send your script to someone else.

Usage

freshr(pkgexc = NULL, varexc = NULL)

Arguments

pkgexc

list of packages to exclude from removal

varexc

list of variables to exclude from removal

Value

This function returns no value. It is called for its side effect of cleaning up the global environment at script's start up/

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.